API
===

Anything documented here is part of the public API that Flask-Magql provides, unless
otherwise indicated. Anything not documented here is considered internal or private and
may change at any time.

Extension
---------

```{eval-rst}
.. currentmodule:: flask_magql
.. autoclass:: MagqlExtension
```
